@@ -389,7 +389,11 @@ class MultiAuth(object):
 class OAuth2(HTTPAuth):
     def __init__(self, client_id, auth_url, redirect_url, auth_function, username_function, debug=None, scope=None, userinfo_url=None): #pylint: disable=super-init-not-called
         def default_auth_error():
-            return "Unauthorized Access (OAuth2)"
+            res = flask.make_response("Unauthorized Access (OAuth2). Your access token may be invalid or is expired, if the latter is the case, simply refresh the page to be redirected login again.")
+            res.set_cookie('oauth_access_token', "",expires=0) #remove cookie
+            res.status_code = 403
+            return res
+
 
 
         self.client_id = client_id
@@ -413,7 +417,8 @@ class OAuth2(HTTPAuth):
             kwargslogin['scope'] = self.scope
         oauthsession = OAuth2Session(self.client_id, **kwargslogin)
         if self.userinfo_url: oauthsession.USERINFO_URL = self.userinfo_url
-        return 'Bearer scope="{0}", auth_server="{1}"'.format(self.scope, self.auth_function(oauthsession, self.auth_url)) #following https://stackoverflow.com/questions/50921816/standard-http-header-to-indicate-location-of-openid-connect-server , realm is OPTIONAL so I skip it here
+        auth_url, _state = self.auth_function(oauthsession, self.auth_url)
+        return 'Bearer auth_server="{0}"'.format(auth_url) #following https://stackoverflow.com/questions/50921816/standard-http-header-to-indicate-location-of-openid-connect-server , realm is OPTIONAL so I skip it here
 
     def get_oauth_access_token_from_request(self):
         oauth_access_token = None
