@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 #-*- coding:utf-8 -*-
 
 ###############################################################
@@ -13,13 +12,15 @@
 #
 ###############################################################
 
+
+#pylint: disable=wrong-import-position, unused-wildcard-import
+
 import sys
 import os
 import time
-import glob
-import random
-import codecs
 import unittest
+import io
+import zipfile
 
 #We may need to do some path magic in order to find the clam.* imports
 
@@ -28,7 +29,7 @@ os.environ['PYTHONPATH'] = sys.path[0] + '/../../'
 
 #Import the CLAM Client API and CLAM Data API and other dependencies
 from clam.common.client import *
-from clam.common.data import *
+from clam.common.data import * #pylint: disable=redefined-builtin
 from clam.common.formats import *
 import clam.common.status
 
@@ -68,13 +69,19 @@ class BasicServiceTest(unittest.TestCase):
 
     def test2_4_upload(self):
         """Basic Service Test - File upload with extension"""
-        f = codecs.open('/tmp/servicetest.txt','w','utf-8')
-        f.write(u"On espère que tout ça marche bien.")
+        f = io.open('/tmp/servicetest.txt','w',encoding='utf-8')
+        f.write("On espère que tout ça marche bien.")
         f.close()
         data = self.client.get('basicservicetest')
         success = self.client.addinputfile('basicservicetest', data.inputtemplate('textinput'),'/tmp/servicetest.txt', language='fr')
         self.assertTrue(success)
 
+    def test2_4b_upload(self):
+        """Basic Service Test - Passing contents explicitly"""
+        data = self.client.get('basicservicetest')
+        success = self.client.addinput('basicservicetest', data.inputtemplate('textinput'),"On espère que tout ça marche bien.",filename='servicetest.txt', language='fr')
+        self.assertTrue(success)
+
     def test2_5_upload(self):
         """Basic Service Test - File upload verification"""
         data = self.client.get('basicservicetest')
@@ -96,8 +103,8 @@ class BasicServiceTest(unittest.TestCase):
 
     def test2_7_upload(self):
         """Basic Service Test - File upload without extension"""
-        f = codecs.open('/tmp/servicetest','w','utf-8')
-        f.write(u"On espère que tout ça marche bien.")
+        f = io.open('/tmp/servicetest','w',encoding='utf-8')
+        f.write("On espère que tout ça marche bien.")
         f.close()
         data = self.client.get('basicservicetest')
         success = self.client.addinputfile('basicservicetest', data.inputtemplate('textinput'),'/tmp/servicetest', language='fr')
@@ -130,17 +137,17 @@ class BasicServiceTest(unittest.TestCase):
         try:
             success = self.client.addinputfile('basicservicetest', data.inputtemplate('textinput'),'/tmp/servicetest', language='nonexistant')
             self.assertFalse(success)
-        except ParameterError, e:
-            print e
-            self.assertTrue(True)
+        except ParameterError as e:
+            print(e)
+            self.assertTrue(True) #pylint: disable=redundant-unittest-assert
 
     def test2_B_metadata(self):
         """Basic Service Test - Upload with explicit metadata file"""
-        f = codecs.open('/tmp/servicetest.txt','w','utf-8')
-        f.write(u"On espère que tout ça marche bien.")
+        f = io.open('/tmp/servicetest.txt','w',encoding='utf-8')
+        f.write("On espère que tout ça marche bien.")
         f.close()
-        f = codecs.open('/tmp/servicetest.txt.METADATA','w','utf-8')
-        f.write(u"""<?xml version="1.0" encoding="UTF-8"?>
+        f = io.open('/tmp/servicetest.txt.METADATA','w',encoding='utf-8')
+        f.write("""<?xml version="1.0" encoding="UTF-8"?>
 <CLAMMetaData format="PlainTextFormat" mimetype="text/plain" inputtemplate="textinput">
 <meta id="encoding">utf-8</meta>
 <meta id="author">proycon</meta>
@@ -163,8 +170,8 @@ class ExtensiveServiceTest(unittest.TestCase):
         self.client = CLAMClient(self.url)
         self.project = 'extservicetest'
         self.client.create(self.project)
-        f = codecs.open('/tmp/servicetest.txt','w','utf-8')
-        f.write(u"On espère que tout ça marche bien.")
+        f = io.open('/tmp/servicetest.txt','w',encoding='utf-8')
+        f.write("On espère que tout ça marche bien.")
         f.close()
 
 
@@ -193,6 +200,22 @@ class ExtensiveServiceTest(unittest.TestCase):
                 #print outputfile.metadata.provenance.outputtemplate_id
                 self.assertTrue(outputfile.metadata.provenance.outputtemplate_id == 'statsbydoc')
 
+    def test1b_downloadarchive(self):
+        """Extensive Service Test - Download Archive (ZIP)"""
+        data = self.client.get(self.project)
+        success = self.client.addinputfile(self.project, data.inputtemplate('textinput'),'/tmp/servicetest.txt', language='fr')
+        self.assertTrue(success)
+        data = self.client.start(self.project)
+        self.assertTrue(data)
+        self.assertFalse(data.errors)
+        while data.status != clam.common.status.DONE:
+            time.sleep(1) #wait 1 second before polling status
+            data = self.client.get(self.project) #get status again
+        self.assertFalse(data.errors)
+        self.assertTrue(isinstance(data.output, list))
+        self.client.downloadarchive(self.project,'/tmp/target.zip','zip')
+        self.assertEqual(zipfile.ZipFile('/tmp/target.zip').testzip(), None) #testing zip file integrity
+
     def test2_parametererror(self):
         """Extensive Service Test - Global parameter error"""
         data = self.client.get(self.project)
@@ -201,8 +224,8 @@ class ExtensiveServiceTest(unittest.TestCase):
         try:
             data = self.client.start(self.project, casesensitive='nonexistant')
             self.assertTrue(data)
-        except ParameterError, e:
-            self.assertTrue(True)
+        except ParameterError:
+            self.assertTrue(True) #pylint: disable=redundant-unittest-assert
 
     def test3_conditionaloutput(self):
         """Extensive Service Test - Output conditional on parameter"""
@@ -231,8 +254,37 @@ class ExtensiveServiceTest(unittest.TestCase):
                 outputfile.loadmetadata()
                 self.assertTrue(outputfile.metadata.provenance.outputtemplate_id == 'lexicon')
 
+    def test4_program(self):
+        """Extensive Service Test - Program integrity test"""
+        data = self.client.get(self.project)
+        success = self.client.addinputfile(self.project, data.inputtemplate('textinput'),'/tmp/servicetest.txt', language='fr')
+        self.assertTrue(success)
+        data = self.client.start(self.project, createlexicon=False)
+        self.assertTrue(data)
+        self.assertFalse(data.errors)
+        while data.status != clam.common.status.DONE:
+            time.sleep(1) #wait 1 second before polling status
+            data = self.client.get(self.project) #get status again
+        self.assertTrue(data.program)
+        self.assertEqual(data.program.matchedprofiles, [0])
+        self.assertEqual(len(data.program), 5)
+        #print("PROGRAM:", data.program,file=sys.stderr)
+        outputfiles = list(data.program.getoutputfiles())
+        #print("OUTPUTFILES:", outputfiles,file=sys.stderr)
+        self.assertEqual(len(outputfiles), 5)
+        for outputfile, outputtemplate in outputfiles:
+            self.assertIn(outputtemplate, ('errorlog', 'overallstats','overallfreqlist','statsbydoc','freqlistbydoc'))
+            if not outputtemplate.startswith('overall') and outputtemplate != 'errorlog':
+                inputfiles = list(data.program.getinputfiles(outputfile))
+                self.assertEqual(len(inputfiles), 1)
+                self.assertEqual(inputfiles[0][1], 'textinput')
+
+
+
+
+
     def tearDown(self):
-        success = self.client.delete(self.project)
+        self.client.delete(self.project)
 
 
 
@@ -243,14 +295,14 @@ class ArchiveUploadTest(unittest.TestCase):
         self.client = CLAMClient(self.url)
         self.project = 'archivetest'
         self.client.create(self.project)
-        f = codecs.open('/tmp/servicetest.txt','w','utf-8')
-        f.write(u"On espère que tout ça marche bien.")
+        f = io.open('/tmp/servicetest.txt','w',encoding='utf-8')
+        f.write("On espère que tout ça marche bien.")
         f.close()
-        f = codecs.open('/tmp/servicetest2.txt','w','utf-8')
-        f.write(u"Non, rien de rien, non je ne regrette rien.")
+        f = io.open('/tmp/servicetest2.txt','w',encoding='utf-8')
+        f.write("Non, rien de rien, non je ne regrette rien.")
         f.close()
-        f = codecs.open('/tmp/servicetest3.txt','w','utf-8')
-        f.write(u"Ni le mal qu'on m'a fait, ni le bien, tout ça me semble égal!")
+        f = io.open('/tmp/servicetest3.txt','w',encoding='utf-8')
+        f.write("Ni le mal qu'on m'a fait, ni le bien, tout ça me semble égal!")
         f.close()
         os.system('zip /tmp/servicetest.zip /tmp/servicetest.txt /tmp/servicetest2.txt /tmp/servicetest3.txt')
         os.system('tar -cvzf /tmp/servicetest.tar.gz /tmp/servicetest.txt /tmp/servicetest2.txt /tmp/servicetest3.txt')
@@ -276,7 +328,7 @@ class ArchiveUploadTest(unittest.TestCase):
         self.assertTrue('servicetest3.txt' in [ x.filename for x in data.input ])
 
     def tearDown(self):
-        success = self.client.delete(self.project)
+        self.client.delete(self.project)
 
 if __name__ == '__main__':
-    unittest.main()
+    unittest.main(verbosity=2)
